pub fn candle_width_to_bar_spec(width: AxCandleWidth) -> BarSpecificationExpand description
Converts an Ax candle width to a Nautilus bar specification.
pub fn candle_width_to_bar_spec(width: AxCandleWidth) -> BarSpecificationConverts an Ax candle width to a Nautilus bar specification.